@@ -62,8 +62,8 @@ knitr::opts_chunk$set(fig.width=5, fig.height=5)
 ## ----googleMap-----------------------------------------------------------
 fireLons <- c(-118.461,-117.679,-120.039,-119.002,-119.662)
 fireLats <- c(48.756,46.11,47.814,48.338,48.519)
-gmap <- monitorGoogleMap(PacNW_dailyAvg, zoom=7, centerLon=-118, centerLat=47, slice=max)
-addIcon('redFlame', fireLons, fireLats, map=gmap, expansion=0.2)
+monitorEsriMap(PacNW_dailyAvg, zoom=7, centerLon=-118, centerLat=47, slice=max)
+addIcon('redFlame', fireLons, fireLats, expansion=.002)
 addAQILegend(cex=0.8)
 title("August, 2015", line=-1.5, cex.main=2)
 
